'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _keys = require('babel-runtime/core-js/object/keys');

var _keys2 = _interopRequireDefault(_keys);

var _extends2 = require('babel-runtime/helpers/extends');

var _extends3 = _interopRequireDefault(_extends2);

var _objectWithoutProperties2 = require('babel-runtime/helpers/objectWithoutProperties');

var _objectWithoutProperties3 = _interopRequireDefault(_objectWithoutProperties2);

exports.default = readConfig;

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/* eslint-disable import/no-dynamic-require,global-require */

// Import chromatic config
var chromaticFilename = 'chromatic.config.js';

function normalizeConfig(config, configDir) {
  // Turn a string like './a,./b' into an array
  function ensureArray(option) {
    if (typeof option === 'string') {
      return option.split(',');
    }
    return option;
  }

  // Make a relative path absolute
  function absolutize(filename) {
    return _path2.default.resolve(configDir, filename);
  }

  // require('foo') acts differently from require('./foo'), we don't need to absolutize
  function absolutizeRequire(filename) {
    return filename.match('/') ? absolutize(filename) : filename;
  }

  var globalStyles = config.globalStyles,
      componentDir = config.componentDir,
      runtimes = config.runtimes,
      webpackConfig = config.webpackConfig,
      rest = (0, _objectWithoutProperties3.default)(config, ['globalStyles', 'componentDir', 'runtimes', 'webpackConfig']);


  var normalizedConfig = (0, _extends3.default)({}, rest);

  if (globalStyles) {
    normalizedConfig.globalStyles = ensureArray(globalStyles).map(absolutizeRequire);
  }

  if (componentDir) {
    normalizedConfig.componentDir = ensureArray(componentDir).map(absolutize);
  }

  if (runtimes) {
    normalizedConfig.runtimes = {};
    (0, _keys2.default)(runtimes).forEach(function (runtime) {
      normalizedConfig.runtimes[runtime] = absolutize(runtimes[runtime]);
    });
  }

  if (webpackConfig) {
    normalizedConfig.webpackConfig = absolutize(webpackConfig);
  }

  return normalizedConfig;
}

function readAndNormalizeConfig(configFilename) {
  var config = require(configFilename);
  var configDir = _path2.default.dirname(configFilename);

  // eslint-disable-next-line no-underscore-dangle
  return normalizeConfig(config.__esModule ? config.default : config, configDir);
}

function getConfig(_ref) {
  var appDir = _ref.appDir,
      config = _ref.config;

  if (config) {
    // If the user specifies config relatively, resolve it compared to appDir
    var filename = _path2.default.resolve(appDir, config);
    return readAndNormalizeConfig(filename);
  }

  // Else look for a config in appDir
  var defaultFilename = _path2.default.join(appDir, chromaticFilename);
  if (_fs2.default.existsSync(defaultFilename)) {
    return readAndNormalizeConfig(defaultFilename);
  }

  // No config found
  return {};
}

function readConfig(options) {
  var configOptions = getConfig(options);

  var normalizedOptions = normalizeConfig(options, options.appDir);
  var optionsWithoutUndefined = {};
  (0, _keys2.default)(normalizedOptions).forEach(function (option) {
    if (typeof normalizedOptions[option] !== 'undefined') {
      optionsWithoutUndefined[option] = normalizedOptions[option];
    }
  });

  // commandline options should override read options
  return (0, _extends3.default)({}, configOptions, optionsWithoutUndefined);
}
//# sourceMappingURL=config.js.map